@@ -1,8 +1,10 @@
-package Cache::Cascade; # git description: Cache-Cascade-0.05-7-g0b8be6d
+package Cache::Cascade; # git description: v0.06-3-g9cbe01e
 # ABSTRACT: Get/set values to/from a group of caches, with some advanced semantics.
 
-use Any::Moose;
+use strictures 2;
+use Moo;
 use Carp qw/croak/;
+use Types::Standard qw(ArrayRef Bool);
 
 sub _eval {
 	my ( $code, %args ) = @_;
@@ -10,23 +12,23 @@ sub _eval {
 	eval $code;
 }
 
-use namespace::clean -except => [qw(meta)];
+use namespace::autoclean;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 has caches => (
-	isa => "ArrayRef",
+	isa => ArrayRef,
 	is  => "rw",
 );
 
 has float_hits => (
-	isa => "Bool",
+	isa => Bool,
 	is  => "rw",
 	default => 0,
 );
 
 has set_deep => (
-	isa => "Bool",
+	isa => Bool,
 	is  => "rw",
 	default => 1,
 );
@@ -117,8 +119,6 @@ CODE
 	}
 }
 
-__PACKAGE__->meta->make_immutable if __PACKAGE__->meta->can("make_immutable");
-
 __PACKAGE__;
 
 __END__
@@ -133,7 +133,7 @@ Cache::Cascade - Get/set values to/from a group of caches, with some advanced se
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
